# Generated by Django 4.2.16 on 2025-11-10 01:18

import datetime

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0033_rollforwardsummary_price_increase_upgrade_or_downgrade'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoicelineitemsummary',
            name='invoice_date',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='invoicelineitemsummary',
            name='sync_date',
            field=models.DateField(default=datetime.date(2025, 11, 10)),
            preserve_default=False,
        ),
    ]
