# Generated by Django 4.2.16 on 2025-11-24 23:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("subscriptionmanager", "0034_invoicelineitemsummary_invoice_date_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoicelineitemsummary",
            name="invoice_date",
            field=models.DateField(db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name="invoicelineitemsummary",
            name="sync_date",
            field=models.DateField(db_index=True),
        ),
    ]
